@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -221,9 +221,14 @@ class ContainerAnalysisAsyncClient:
         )
 
     def get_grafeas_client(self) -> grafeas_v1.GrafeasClient:
-        transport = type(self).get_transport_class("grpc_asyncio")()
         grafeas_transport = grafeas_v1.services.grafeas.transports.GrafeasGrpcTransport(
-            host=transport._host, scopes=transport.AUTH_SCOPES
+            credentials=self.transport._credentials,
+            # Set ``credentials_file`` to ``None`` here as
+            # transport._credentials contains the credentials
+            # which are saved
+            credentials_file=None,
+            host=self.transport._host,
+            scopes=self.transport.AUTH_SCOPES,
         )
         return grafeas_v1.GrafeasClient(transport=grafeas_transport)
 
@@ -249,7 +254,7 @@ class ContainerAnalysisAsyncClient:
         occurrences.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud.devtools import containeranalysis_v1
 
@@ -403,7 +408,7 @@ class ContainerAnalysisAsyncClient:
         occurrences.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud.devtools import containeranalysis_v1
 
@@ -557,7 +562,7 @@ class ContainerAnalysisAsyncClient:
         occurrences.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud.devtools import containeranalysis_v1
 
@@ -664,7 +669,7 @@ class ContainerAnalysisAsyncClient:
         occurrences.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud.devtools import containeranalysis_v1
 
