@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -406,9 +406,14 @@ class ContainerAnalysisClient(metaclass=ContainerAnalysisClientMeta):
             )
 
     def get_grafeas_client(self) -> grafeas_v1.GrafeasClient:
-        transport = type(self).get_transport_class("grpc")()
         grafeas_transport = grafeas_v1.services.grafeas.transports.GrafeasGrpcTransport(
-            host=transport._host, scopes=transport.AUTH_SCOPES
+            credentials=self.transport._credentials,
+            # Set ``credentials_file`` to ``None`` here as
+            # transport._credentials contains the credentials
+            # which are saved
+            credentials_file=None,
+            host=self.transport._host,
+            scopes=self.transport.AUTH_SCOPES,
         )
         return grafeas_v1.GrafeasClient(transport=grafeas_transport)
 
@@ -434,8 +439,7 @@ class ContainerAnalysisClient(metaclass=ContainerAnalysisClientMeta):
         occurrences.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud.devtools import containeranalysis_v1
 
@@ -588,8 +592,7 @@ class ContainerAnalysisClient(metaclass=ContainerAnalysisClientMeta):
         occurrences.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud.devtools import containeranalysis_v1
 
@@ -742,8 +745,7 @@ class ContainerAnalysisClient(metaclass=ContainerAnalysisClientMeta):
         occurrences.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud.devtools import containeranalysis_v1
 
@@ -849,8 +851,7 @@ class ContainerAnalysisClient(metaclass=ContainerAnalysisClientMeta):
         occurrences.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud.devtools import containeranalysis_v1
 
